@@ -160,7 +160,8 @@ class UserRole(object):
     }
     # 扶摇上权限管理角色的权重顺序, 从高到低
     ROLE_WEIGHT = ['dev', 's_customer', 'j_customer', 'louceng', 'guide']
-    
+
+
 class ReturnQuantityType(object):
     # 退货单&订单上使用的退款数量类型
     # 部分退
@@ -189,8 +190,8 @@ class ShippingMethod(object):
     FLASH_DELIVERY = 'flash_delivery'
 
     CHOICES = (
-        (EXPRESS, "快递"),
-        (SELF_SERVICE, "自提"),
+        (EXPRESS, "快递配送"),
+        (SELF_SERVICE, "到店自提"),
         (NO_NEED_DELIVERY, "无需配送"),
         (FLASH_DELIVERY, "闪送"),
         (SELF_FLASH, "自费闪送"),
@@ -233,3 +234,5 @@ class ShippingMethod(object):
 
 # 汉光仓ID
 HG_STORAGE_ID = "0"
+# 汉光外仓ID, 用于给一些不是外仓发货的专柜转外仓用
+HG_STORAGE_N_ID = "-1"
