@@ -7,6 +7,7 @@ logger = logging.getLogger(__name__)
 
 # write_to_excel：把data数据写入到excel中
 def write_to_excel(named_result, sheet_name):
+    err_msg = ""
     output = BytesIO()
     workbook = xlsxwriter.Workbook(output)
     ws = workbook.add_worksheet(sheet_name)
@@ -21,10 +22,13 @@ def write_to_excel(named_result, sheet_name):
                     columns.append(k)
 
                 if len(columns) > 0:
-                    ws.write_row(0, 0, columns, bold)
+                    ws.write(0, 0, "序号", bold)
+                    ws.write_row(0, 1, columns, bold)
                     row_idx = 1
+
                     for d in named_result[0]:
-                        ws.write_row(row_idx, 0, d)
+                        ws.write(row_idx, 0, row_idx)
+                        ws.write_row(row_idx, 1, d)
                         row_idx += 1
             elif len(named_result) > 1 and len(named_result[1]) > 0:
                 ws.write_string(0, 0, named_result[1])
@@ -32,7 +36,7 @@ def write_to_excel(named_result, sheet_name):
         err_msg = "保存excel处理数据时时失败,原因: {be_str}".format(be_str=str(e))
         ws.write_string(0, 0, err_msg)
         logger.error(err_msg)
-
-    workbook.close()
+    finally:
+        workbook.close()
     xlsx_data = output.getvalue()
-    return xlsx_data
+    return xlsx_data, err_msg
