@@ -1,6 +1,17 @@
 from ..core.datastructures import ImmutableList
 
 
+class AfsLineStatus:
+    ''' 退款单表体状态 '''
+    # 导购收货
+    # GUIDE_RECEIVED = "GuideReceived"
+    GUIDE_RECEIVED = "guide_received"
+
+    CHOICES = (
+        (GUIDE_RECEIVED, "导购收货"),
+    )
+
+
 class Aftersale_Number_Refund_Status(object):
     # 退单子退款状态(init初始/doing进行中/done已完成)
     INIT = "init"
