@@ -9,6 +9,7 @@ from django.contrib.auth import get_user_model
 from django.utils.functional import cached_property
 
 from ..core.constants import PayType
+from ..core.constants import ReturnQuantityType
 from ..core.constants import ShippingPartnerCodes_DICT
 from ..core.base_models import BaseModelTimeAndDeleted
 from ..core.model_function import get_object_or_None
@@ -21,6 +22,7 @@ from ..sparrow_aftersale.constants import AftersaleSource
 from ..sparrow_aftersale.constants import AftersaleCancelSource
 from ..sparrow_aftersale.constants import AftersaleActions
 from ..sparrow_aftersale.constants import AfterSaleType
+from ..sparrow_aftersale.constants import AfsLineStatus
 from ..sparrow_orders.constants import CouponSource
 from ..sparrow_orders.constants import PayStepType
 from ..sparrow_orders.constants import PayMethod
@@ -58,6 +60,9 @@ __all__ = [
     'VLines',
     'VLinePayment',
     'VLinePromotion',
+    'QueryResult',
+    'QueryResultTicket',
+    'QueryResultDetail',
 ]
 
 
@@ -229,6 +234,18 @@ class Afs(BaseModelTimeAndDeleted):
     # 退货重算-售后单版本号
     afs_version = models.CharField("售后版本号", max_length=12, blank=True, null=True, db_index=True, default=AfsVersionConst.V2)
 
+    # V3售后是否重新计算
+    if_recomputed_v3 = models.BooleanField("V3售后是否重新计算", null=True, default=None)
+
+    # 2022.08 售后单表头冗余商品总数量、退款总金额
+    total_quantity = models.IntegerField('商品总数量', null=True, blank=True, default=0)
+    # refund_amount 退款总金额, 包含各种支付别, 不包含 postage
+    refund_amount = models.DecimalField("refund_amount", decimal_places=2, max_digits=12, blank=True, null=True)
+
+    # 2022.10.17 售后单表头冗余订单商品总数量 & 退货数量类型
+    order_total_quantity = models.IntegerField('商品总数量', null=True, blank=True, default=0)
+    return_quantity_type = models.CharField("退货数量类型", max_length=24, choices=ReturnQuantityType.RETURN_QUANTITY_TYPE_CHOICES, blank=True, null=True, default=ReturnQuantityType.NONE)
+
     class Meta:
         app_label = APP_LABEL
         verbose_name = "Order After Sale"
@@ -679,6 +696,26 @@ class AfsLine(BaseModelTimeAndDeleted):
         "数据来源", max_length=12, blank=True, null=True, 
         db_index=True, choices=AfsLineGenerateFrom.CHOICES, default=AfsLineGenerateFrom.SELECT)
 
+    # refund_amount 退款总金额, 包含各种支付别
+    refund_amount = models.DecimalField("refund_amount", decimal_places=2, max_digits=12, blank=True, null=True)
+
+    # 2022.08 订单冗余sell_type
+    sell_type = models.CharField("sell_type", max_length=32, blank=True, null=True, db_index=True)
+
+    # 2022.09 冗余确收人
+    afs_sub_num_shop = models.CharField("退款单小票票号", max_length=64, blank=True, null=True)
+
+    # 2022.11 发货仓需求
+    retstorage_id = models.CharField("退货仓ID", max_length=40, blank=True, null=True, db_index=True)
+    # 2022.10 新增售后单行状态
+    afsline_status = models.CharField("afsline_status", max_length=32, choices=AfsLineStatus.CHOICES, blank=True, null=True)
+    # 客服还货时, 导购收货人信息
+    guide_receiver = models.CharField("导购收货人", max_length=40, blank=True, null=True, db_index=True)
+    guide_receiver_username = models.CharField("导购收货人手机号", max_length=20, blank=True, null=True, db_index=True)
+    guide_receiver_displayname = models.CharField("导购收货人姓名", max_length=40, blank=True, null=True)
+    # guide_receiver_time (导购收货时间)
+    guide_receiver_time = models.DateTimeField("导购收货时间", blank=True, null=True)
+
     class Meta:
         # 同一个售后单里不应该创建两个相同发货单行的售后
         # unique_together = ('aftersale_id', 'line_id', 'distribute_line_id')
@@ -1414,3 +1451,83 @@ class AfsVlinesPointsCharge(BaseModelTimeAndDeleted):
 
     class Meta:
         app_label = 'sparrow_aftersale'
+
+
+# 打印退款单小票的二维码
+# 一个二维码 属于同一个售后单
+# 如果同时勾选了多个专柜的商品，会打印多张小票
+class QueryResult(BaseModelTimeAndDeleted):
+    # id(主键uuid)
+    id = models.CharField(max_length=100, primary_key=True, default=get_uuid4_hex, editable=False)
+    # user_id 操作员ID
+    query_user_id = models.CharField('User ID', max_length=40, db_index=True, null=True)
+    # username 操作员手机号
+    query_username = models.CharField('操作员手机号', max_length=15, help_text=u'操作员手机号', blank=True, null=True)
+    # displayname 操作员姓名
+    query_displayname = models.CharField("操作员姓名", max_length=10, blank=True, null=True)
+    # 售后单ID
+    aftersale_id = models.IntegerField("售后单ID", blank=True, null=True, db_index=True)
+    # 售后小票单号
+    afs_sub_num = models.CharField("售后小票单号", max_length=64, blank=True, null=True, db_index=True)
+
+    class Meta:
+        app_label = 'sparrow_aftersale'
+        ordering = ['-created_time']
+
+
+# 退款单小票，所属某个专柜
+class QueryResultTicket(BaseModelTimeAndDeleted):
+    # user_id 操作员ID
+    query_user_id = models.CharField('User ID', max_length=40, db_index=True, null=True)
+    # username 操作员手机号
+    query_username = models.CharField('操作员手机号', max_length=15, help_text=u'操作员手机号', blank=True, null=True)
+    # displayname 操作员姓名
+    query_displayname = models.CharField("操作员姓名", max_length=10, blank=True, null=True)
+    # 二维码ID
+    query_result_id = models.CharField(max_length=40, blank=True, null=True, db_index=True)
+    # 售后单ID
+    aftersale_id = models.IntegerField("售后单ID", blank=True, null=True, db_index=True)
+    # 售后小票单号
+    afs_sub_num_shop = models.CharField("售后小票单号", max_length=64, blank=True, null=True, unique=True, db_index=True)
+    # shop_id(专柜id)
+    shop_id = models.PositiveIntegerField('Shop ID', blank=True, null=True)
+    # shop_num(专柜号)
+    shop_num = models.CharField("Shop number", max_length=128, blank=True)
+    # 专柜名
+    shop_name = models.CharField("Shop Name", max_length=128, blank=True, null=True)
+    # 小票包含的商品数量
+    quantity = models.IntegerField("退货数量", default=1)
+
+
+# 退款单小票line
+class QueryResultDetail(BaseModelTimeAndDeleted):
+    # id(主键uuid)
+    id = models.CharField(max_length=40, primary_key=True, default=get_uuid4_hex, editable=False)
+    query_result_id = models.CharField(max_length=40, blank=True, null=True, db_index=True)
+    aftersale_id = models.IntegerField("售后单ID", blank=True, null=True, db_index=True)
+    afsline_id = models.IntegerField("售后单表体ID", blank=True, null=True, db_index=True)
+
+    # 以下字段是上线后做优化新增
+    # 退款单小票票号, 每个专柜一张
+    afs_sub_num_shop = models.CharField("退款单小票票号", max_length=64, null=True)
+
+    # shop_id(专柜id)
+    shop_id = models.PositiveIntegerField('Shop ID', blank=True, null=True)
+    # shop_num(专柜号)
+    shop_num = models.CharField("Shop number", max_length=128, blank=True)
+    # 专柜名
+    shop_name = models.CharField("Shop Name", max_length=128, blank=True, null=True)
+    # title(商品名称)
+    title = models.CharField("Product title", max_length=255, blank=True, null=True)
+    shop_sku = models.CharField("Shop SKU", max_length=128, blank=True, null=True)
+    brand_name = models.CharField("Brand Name", max_length=128, blank=True, null=True)
+    sku_attr = models.CharField("Product SKU Attr", max_length=255, blank=True, null=True)
+    # 商品汉光码
+    hg_code = models.CharField("Product HG Code", max_length=255, blank=True, null=True)
+
+    # 退商品数量
+    quantity = models.IntegerField('退货数量', default=1)
+
+    class Meta:
+        app_label = 'sparrow_aftersale'
+        ordering = ['-created_time']
